﻿Copyright (c) (2014) Fluke Corporation.                  All rights reserved.
=============================================================================
INSTRUMENT:            Sub Tek TPS2000 (1 yr) ExTrig Sens RS-232 /9500+1Hd
DATE:                  2014-03-13 14:17:28
AUTHOR:                Fluke
REVISION:              $Revision: 7612 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       147
CONFIGURATION:         Datron 9500
CONFIGURATION:         Datron 9510 on channel 1
=============================================================================
#
#  Procedure Author:
#        VY, GMO
#
#  Model(s) Covered:
#        TPS 2012, TPS 2014, TPS 2024, TPS 2012B, TPS 2014B, TPS 2024B
#
#  Compatibility:
#        MET/CAL version 8.1.4 or later
#
#  Additional Equipment Required:
#        Power Splitter, 1 kHz to 500 MHz, 6 dB insertion loss,
#        output tracking: <0.25 dB, equivalent output
#        SWR: <1.22, HP/Agilent 11667A or equivalent
#        N(f) all ports
#        N(m) to BNC(f) adapter, 3 sets
#        50 Ω feed through terminator, 2 sets
#        50 Ω BNC(m)-(m) cable, 10 inch long, 2 sets
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  CALL         Sub Tek TPS2000 Cal Initialize RS-232

  1.002  IF           @Chan == 1
  1.003  RSLT         =
  1.004  RSLT         =EXTERNAL EDGE-TRIGGER SENSITIVITY
  1.005  ENDIF

  1.006  RSLT         =
  1.007  RSLT         = Channel [V @Chan]
  1.008  HEAD         CH [V @Chan] EXTERNAL EDGE-TRIGGER SENSITIVITY
  1.009  TARGET
  1.010  DISP         Connect the CH 1 Active Head to the input of a 2 way
  1.010  DISP         power splitter via a N(m) to BNC(f) adapter.
  1.010  DISP
  1.010  DISP         Connect one output of the power splitter to UUT
  1.010  DISP         CH [V @Chan] via a N(m) to BNC(f) adapter, a BNC(m)-(m)
  1.010  DISP         cable and a 50 Ω feed through terminator.
  1.010  DISP
  1.010  DISP         Connect the other output of the power splitter to UUT
  1.010  DISP         EXT TRIG via a N(m) to BNC(f) adapter, a BNC(m)-(m)
  1.010  DISP         cable and a 50 Ω feed through terminator.
  1.011  PORT         CH[V @Chan]:PRO 1;SCA 500E-3
  1.012  PORT         HOR:SCA 10E-9
  1.013  PORT         TRIG:MAI:MOD NORM;EDGE:SOU EXT
  1.014  PORT         MEASU:MEAS[V @Chan]:SOU CH[V @Chan];TYP PK2

# Firstly set the output of the calibrator so the peak-to-peak measurement is
# approximately 2 Vpp, for the reason of using power slitter the output of
# calibrator is approximately twice of peak-to-peak measurement, i.e 4 Vpp.
  1.015  MATH         MEM = 2; MEM1 = 4

  1.016  DO
  1.017  MATH         MEM = MEM1 + (4 - 2 * MEM) / 2

# Set the output trap in order to avoid the calculated output beyond the
# calibrator maximum or minimum output at this frequency because of unstable
# reading.
  1.018  IF           MEM > 5.56 || MEM < 0.00444
  1.019  MATH         MEM = 4
  1.020  ENDIF

  1.021  IF           ZCMPI (@Bandwidth,"100 MHz")
  1.022  9500         Vpp                          100MH          LS    S  L
  1.023  ELSEIF       ZCMPI (@Bandwidth,"200 MHz")
  1.024  9500         Vpp                          200MH          LS    S  L
  1.025  ENDIF

  1.026  MATH         @PeakValue = MEM1 / 4
  1.027  CALL         Sub Tek TPS2000 Trigger Chk and Level Adj RS-232
  1.028  PORT         [D500]MEASU:MEAS[V @Chan]:VAL?[I]
  1.029  UNTIL        (MEM >= 1.90) && (MEM <= 2.10)

# Then attenuate the output of calibrator to half so the input of UUT is
# is approximately 1 Vpp that is just the required test signal for external
# trig sensitivity.
  1.030  MATH         VppStd = MEM1 / 2
  1.031  MATH         MEM = VppStd

  1.032  IF           ZCMPI (@Bandwidth,"100 MHz")
  1.033  9500         Vpp                          100MH          LS    S  L
  1.034  MATH         TestFreq = "100 MHz"
  1.035  ELSEIF       ZCMPI (@Bandwidth,"200 MHz")
  1.036  9500         Vpp                          200MH          LS    S  L
  1.037  MATH         TestFreq = "200 MHz"
  1.038  ENDIF

  1.039  WAIT         -t 5 System settling...
  1.040  MATH         @PeakValue = MEM1 / 2 * 1E-3
  1.041  CALL         Sub Tek TPS2000 Trigger Chk and Level Adj RS-232
  1.042  MATH         ResultStr = " Rising Slope, 2 div at " & TestFreq
  1.043  EVAL   -e @Trigged : [V ResultStr]

  2.001  JMPL         FALL_EDGE_EXSENS

# This TARGET and JMPL are here so "Repeat" and "Cancel" will perform
# a new waveform acquisition.
  2.002  TARGET
# Recall the saved output value of calibrator to set up output again.
  2.003  MATH         MEM = VppStd

  2.004  IF           ZCMPI (@Bandwidth,"100 MHz")
  2.005  9500         Vpp                          100MH          LS    S  L
  2.006  MATH         TestFreq = "100 MHz"
  2.007  ELSEIF       ZCMPI (@Bandwidth,"200 MHz")
  2.008  9500         Vpp                          200MH          LS    S  L
  2.009  MATH         TestFreq = "200 MHz"
  2.010  ENDIF

  2.011  WAIT         -t 5 System settling...

  2.012  LABEL        FALL_EDGE_EXSENS
  2.013  PORT         TRIG:MAI:EDGE:SLO FALL
# Save the peak value of signal for later checking the trigger status.
  2.014  MATH         @PeakValue = MEM1 / 2 * 1E-3
  2.015  CALL         Sub Tek TPS2000 Trigger Chk and Level Adj RS-232
  2.016  MATH         ResultStr = " Falling Slope, 2 div at " & TestFreq
  2.017  EVAL   -e @Trigged : [V ResultStr]

  3.001  PORT         TRIG:MAI:EDGE:SLO RISE
  3.002  9500         *                                                 S
  3.003  END
